DropDownListView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DropDownListView
Constructors
-
DropDownListView({Key? key, bool safeArea = true, required OnValueChanged onValueChanged, required List<
String> items, Curve curve = Curves.ease, ScrollPhysics physics = const NeverScrollableScrollPhysics(), double elevation = 5, int defaultItemIndex = 0, double transitionPerPixel = 0.5, IconData iconData = Icons.arrow_drop_down, required DropdownButtonWidgetBuilder dropdownButtonBuilder, required DropdownItemWidgetBuilder dropdownItemBuilder})
Properties
- curve ↔ Curve
-
getter/setter pair
- defaultItemIndex ↔ int
-
getter/setter pair
- dropdownButtonBuilder ↔ DropdownButtonWidgetBuilder
-
getter/setter pair
- dropdownItemBuilder ↔ DropdownItemWidgetBuilder
-
getter/setter pair
- elevation ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconData ↔ IconData
-
getter/setter pair
-
items
↔ List<
String> -
getter/setter pair
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
getter/setter pair
- onMenuClose ↔ VoidCallback?
-
getter/setter pair
- onMenuOpen ↔ VoidCallback?
-
getter/setter pair
- onValueChanged ↔ OnValueChanged
-
getter/setter pair
- onWidgetTransition ↔ OnWidgetTransition?
-
getter/setter pair
- physics ↔ ScrollPhysics
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safeArea ↔ bool
-
getter/setter pair
- transitionPerPixel ↔ double
-
getter/setter pair
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _DropDownListViewState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited